@@ -32,9 +32,9 @@ Modifications Copyright (C) 2008-2019 Vinay Sajip. All rights reserved.
 A unittest harness (test_gnupg.py) has also been added.
 """
 
-__version__ = "0.4.4"
+__version__ = "0.4.5"
 __author__ = "Vinay Sajip"
-__date__  = "$24-Jan-2019 08:43:25$"
+__date__  = "$12-Aug-2019 15:58:03$"
 
 try:
     from io import StringIO
@@ -813,6 +813,9 @@ class GPG(object):
         """
         self.gpgbinary = gpgbinary
         self.gnupghome = gnupghome
+        # issue 112: fail if the specified value isn't a directory
+        if gnupghome and not os.path.isdir(gnupghome):
+            raise ValueError('gnupghome should be a directory (it isn\'t): %s' % gnupghome)
         if keyring:
             # Allow passing a string or another iterable. Make it uniformly
             # a list of keyring filenames
@@ -997,6 +1000,8 @@ class GPG(object):
         if writer is not None:
             writer.join()
         process.wait()
+        if process.returncode != 0:
+            logger.warning('gpg returned a non-zero error code: %d', process.returncode)
         if stdin is not None:
             try:
                 stdin.close()
@@ -1088,7 +1093,8 @@ class GPG(object):
         """Verify the signature on the contents of the string 'data'
 
         >>> GPGBINARY = os.environ.get('GPGBINARY', 'gpg')
-        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome="keys")
+        >>> if not os.path.isdir('keys'): os.mkdir('keys')
+        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome='keys')
         >>> input = gpg.gen_key_input(passphrase='foo')
         >>> key = gpg.gen_key(input)
         >>> assert key
@@ -1149,14 +1155,17 @@ class GPG(object):
     # KEY MANAGEMENT
     #
 
-    def import_keys(self, key_data):
+    def import_keys(self, key_data, extra_args=None):
         """
         Import the key_data into our keyring.
         """
         result = self.result_map['import'](self)
         logger.debug('import_keys: %r', key_data[:256])
         data = _make_binary_stream(key_data, self.encoding)
-        self._handle_io(['--import'], data, result, binary=True)
+        args = ['--import']
+        if extra_args:
+            args.extend(extra_args)
+        self._handle_io(args, data, result, binary=True)
         logger.debug('import_keys result: %r', result.__dict__)
         data.close()
         return result
@@ -1167,7 +1176,8 @@ class GPG(object):
         >>> import shutil
         >>> shutil.rmtree("keys", ignore_errors=True)
         >>> GPGBINARY = os.environ.get('GPGBINARY', 'gpg')
-        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome="keys")
+        >>> if not os.path.isdir('keys'): os.mkdir('keys')
+        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome='keys')
         >>> os.chmod('keys', 0x1C0)
         >>> result = gpg.recv_keys('pgp.mit.edu', '92905378')
         >>> if 'NO_EXTERNAL_TESTS' not in os.environ: assert result
@@ -1225,6 +1235,8 @@ class GPG(object):
         else:
             fingerprints = [no_quote(fingerprints)]
         args = ['--delete-%s' % which]
+        if secret and self.version >= (2, 1):
+            args.insert(0, '--yes')
         args.extend(fingerprints)
         result = self.result_map['delete'](self)
         if not secret or self.version < (2, 1):
@@ -1318,7 +1330,8 @@ class GPG(object):
         >>> import shutil
         >>> shutil.rmtree("keys", ignore_errors=True)
         >>> GPGBINARY = os.environ.get('GPGBINARY', 'gpg')
-        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome="keys")
+        >>> if not os.path.isdir('keys'): os.mkdir('keys')
+        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome='keys')
         >>> input = gpg.gen_key_input(passphrase='foo')
         >>> result = gpg.gen_key(input)
         >>> fp1 = result.fingerprint
@@ -1374,6 +1387,7 @@ class GPG(object):
         >>> import shutil
         >>> shutil.rmtree('keys', ignore_errors=True)
         >>> GPGBINARY = os.environ.get('GPGBINARY', 'gpg')
+        >>> if not os.path.isdir('keys'): os.mkdir('keys')
         >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome='keys')
         >>> os.chmod('keys', 0x1C0)
         >>> result = gpg.search_keys('<vinay_sajip@hotmail.com>')
@@ -1416,7 +1430,8 @@ class GPG(object):
         control input.
 
         >>> GPGBINARY = os.environ.get('GPGBINARY', 'gpg')
-        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome="keys")
+        >>> if not os.path.isdir('keys'): os.mkdir('keys')
+        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome='keys')
         >>> input = gpg.gen_key_input(passphrase='foo')
         >>> result = gpg.gen_key(input)
         >>> assert result
@@ -1525,7 +1540,8 @@ class GPG(object):
         >>> if os.path.exists("keys"):
         ...     shutil.rmtree("keys", ignore_errors=True)
         >>> GPGBINARY = os.environ.get('GPGBINARY', 'gpg')
-        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome="keys")
+        >>> if not os.path.isdir('keys'): os.mkdir('keys')
+        >>> gpg = GPG(gpgbinary=GPGBINARY, gnupghome='keys')
         >>> input = gpg.gen_key_input(name_email='user1@test', passphrase='pp1')
         >>> result = gpg.gen_key(input)
         >>> fp1 = result.fingerprint
