@@ -28,7 +28,7 @@ except ImportError:
 import gnupg
 
 __author__ = "Vinay Sajip"
-__date__  = "$24-Jan-2019 08:43:59$"
+__date__  = "$12-Aug-2019 15:58:32$"
 
 ALL_TESTS = True
 
@@ -551,6 +551,19 @@ class GPGTestCase(unittest.TestCase):
         expected = type(chunks[0])().join(chunks)
         self.assertEqual(expected.decode('ascii'), data)
 
+        # test signing with encryption and verification during decryption
+        logger.debug('encrypting with signature')
+        gpg.on_data = None
+        edata = str(gpg.encrypt(data, barbara, sign=andrew, passphrase='andy'))
+        logger.debug('decrypting with verification')
+        ddata = gpg.decrypt(edata, passphrase='bbrown')
+        self.assertEqual(data.encode('ascii'), ddata.data, 'Round-trip must work')
+        sig_values = list(ddata.sig_info.values())
+        self.assertTrue(sig_values)
+        sig_info = sig_values[0]
+        self.assertEqual(sig_info['fingerprint'], andrew)
+        logger.debug('decrypting with verification succeeded')
+
     def test_import_and_export(self):
         "Test that key import and export works"
         logger.debug("test_import_and_export begins")
@@ -744,6 +757,14 @@ class GPGTestCase(unittest.TestCase):
             gnupg.GPG(gnupghome=self.homedir, gpgbinary='frob')
         self.assertIn('frob', str(ar.exception))
 
+    def test_invalid_home(self):
+        "Test that any specified gnupghome directory actually is one"
+        hd = tempfile.mkdtemp(prefix='keys-')
+        shutil.rmtree(hd)  # make sure it isn't there anymore
+        with self.assertRaises(ValueError) as ar:
+            gnupg.GPG(gnupghome=hd)
+        self.assertTrue('gnupghome should be a directory' in str(ar.exception))
+
     def test_make_args(self):
         "Test argument line construction"
         self.gpg.options = ['--foo', '--bar']
@@ -819,7 +840,7 @@ class GPGTestCase(unittest.TestCase):
         self.do_file_encryption_and_decryption(encfname, decfname)
         logger.debug("test_file_encryption_and_decryption ends")
 
-    #@skipIf(os.name == 'nt', 'Test not suitable for Windows')
+    @skipIf(os.name == 'nt', 'Test not suitable for Windows')
     def test_invalid_outputs(self):
         "Test encrypting to invalid output files"
         encfno, encfname = tempfile.mkstemp()
@@ -1009,7 +1030,7 @@ TEST_GROUPS = {
     'basic' : set(['test_environment', 'test_list_keys_initial',
                    'test_nogpg', 'test_make_args',
                    'test_quote_with_shell']),
-    'test': set(['test_signature_verification']),
+    'test': set(['test_encryption_and_decryption']),
 }
 
 def suite(args=None):
@@ -1039,6 +1060,7 @@ def init_logging():
 
 def main():
     init_logging()
+    logger.debug('Python version: %s', sys.version.replace('\n', ' '))
     tests = suite()
     results = unittest.TextTestRunner(verbosity=1).run(tests)
     return not results.wasSuccessful()
